@@ -652,7 +652,7 @@ static int stress_cyclic(stress_args_t *args)
 			"be %" PRIu64 " seconds\n", args->name, timeout);
 	}
 
-	if ((instances > 1) && (args->instance == 0)) {
+	if ((instances > 1) && (stress_instance_zero(args))) {
 		pr_inf("%s: for best results, run just 1 instance of "
 			"this stressor\n", args->name);
 	}
@@ -661,8 +661,9 @@ static int stress_cyclic(stress_args_t *args)
 						PROT_READ | PROT_WRITE,
 						MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 	if (rt_stats == MAP_FAILED) {
-		pr_inf_skip("%s: mmap of shared statistics data failed: %d (%s)\n",
-			args->name, errno, strerror(errno));
+		pr_inf_skip("%s: mmap of shared statistics data failed%s, errno=%d (%s)\n",
+			args->name, stress_get_memfree_str(),
+			errno, strerror(errno));
 		return EXIT_NO_RESOURCE;
 	}
 	stress_set_vma_anon_name(rt_stats, size, "rt-statistics");
@@ -673,8 +674,9 @@ static int stress_cyclic(stress_args_t *args)
 						PROT_READ | PROT_WRITE,
 						MAP_SHARED | MAP_ANONYMOUS, -1, 0);
 	if (rt_stats->latencies == MAP_FAILED) {
-		pr_inf_skip("%s: mmap of %zd samples failed: %d (%s)\n",
-			args->name, cyclic_samples, errno, strerror(errno));
+		pr_inf_skip("%s: mmap of %zu samples failed%s, errno=%d (%s)\n",
+			args->name, cyclic_samples, stress_get_memfree_str(),
+			errno, strerror(errno));
 		(void)munmap((void *)rt_stats, size);
 		return EXIT_NO_RESOURCE;
 	}
@@ -700,7 +702,7 @@ static int stress_cyclic(stress_args_t *args)
 		}
 	}
 
-	if (args->instance == 0)
+	if (stress_instance_zero(args))
 		pr_dbg("%s: using method '%s'\n", args->name, cyclic_methods[cyclic_method].name);
 
 	stress_set_proc_state(args->name, STRESS_STATE_SYNC_WAIT);
@@ -799,7 +801,7 @@ redo_policy:
 
 				if (count == 0)
 					pr_fail("%s: sched_setscheduler "
-						"failed: errno=%d (%s) "
+						"failed, errno=%d (%s) "
 						"for scheduler policy %s%s\n",
 						args->name, errno, strerror(errno),
 						cyclic_policies[cyclic_policy].name,
@@ -834,7 +836,7 @@ tidy:
 
 	stress_rt_stats(rt_stats);
 
-	if (args->instance == 0) {
+	if (stress_instance_zero(args)) {
 		if (rt_stats->index) {
 			size_t i;
 
@@ -921,7 +923,7 @@ static const stress_opt_t opts[] = {
 const stressor_info_t stress_cyclic_info = {
 	.stressor = stress_cyclic,
 	.supported = stress_cyclic_supported,
-	.class = CLASS_SCHEDULER | CLASS_OS,
+	.classifier = CLASS_SCHEDULER | CLASS_OS,
 	.opts = opts,
 	.init = stress_cyclic_init,
 	.deinit = stress_cyclic_deinit,
