@@ -1464,7 +1464,7 @@ static void bad_preadv(stress_bad_addr_t *ba, volatile uint64_t *counter)
 		fd = open("/dev/zero", O_RDONLY);
 		if (fd > -1) {
 			(*counter)++;
-			VOID_RET(ssize_t, readv(fd, (struct iovec *)ba->addr, 1));
+			VOID_RET(ssize_t, preadv(fd, (struct iovec *)ba->addr, 1, 0));
 			VOID_RET(int, close(fd));
 		}
 	}
@@ -1652,7 +1652,7 @@ static void bad_readlink3(stress_bad_addr_t *ba, volatile uint64_t *counter)
 	}
 }
 
-#if defined(HAVE_SYS_UIO_H)
+#if defined(HAVE_READV)
 static void bad_readv(stress_bad_addr_t *ba, volatile uint64_t *counter)
 {
 	if (ba->unwriteable) {
@@ -2054,7 +2054,7 @@ static void bad_write(stress_bad_addr_t *ba, volatile uint64_t *counter)
 	}
 }
 
-#if defined(HAVE_SYS_UIO_H)
+#if defined(HAVE_WRITEV)
 static void bad_writev(stress_bad_addr_t *ba, volatile uint64_t *counter)
 {
 	if (ba->unreadable) {
@@ -2072,7 +2072,7 @@ static void bad_writev(stress_bad_addr_t *ba, volatile uint64_t *counter)
 UNEXPECTED
 #endif
 
-static stress_bad_syscall_t bad_syscalls[] = {
+static const stress_bad_syscall_t bad_syscalls[] = {
 	bad_access,
 /*
 	bad_acct,
@@ -2310,7 +2310,7 @@ static stress_bad_syscall_t bad_syscalls[] = {
 	bad_readlink1,
 	bad_readlink2,
 	bad_readlink3,
-#if defined(HAVE_SYS_UIO_H)
+#if defined(HAVE_READV)
 	bad_readv,
 #endif
 #if defined(HAVE_REMOVEXATTR) &&	\
@@ -2371,7 +2371,7 @@ static stress_bad_syscall_t bad_syscalls[] = {
 	bad_waitid,
 #endif
 	bad_write,
-#if defined(HAVE_SYS_UIO_H)
+#if defined(HAVE_WRITEV)
 	bad_writev,
 #endif
 };
@@ -2450,13 +2450,14 @@ static inline int stress_do_syscall(stress_args_t *args)
 		}
 		_exit(EXIT_SUCCESS);
 	} else {
-		int ret, status;
+		pid_t ret;
+		int status;
 
 		ret = shim_waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
-				pr_dbg("%s: waitpid(): errno=%d (%s)\n",
-					args->name, errno, strerror(errno));
+				pr_dbg("%s: waitpid() on PID %" PRIdMAX" failed, errno=%d (%s)\n",
+					args->name, (intmax_t)pid, errno, strerror(errno));
 			(void)stress_kill_pid_wait(pid, &status);
 		}
 		rc = WEXITSTATUS(status);
@@ -2516,9 +2517,10 @@ static int stress_sysbadaddr(stress_args_t *args)
 		sizeof(*state), PROT_READ | PROT_WRITE,
 		MAP_ANONYMOUS | MAP_SHARED, -1, 0);
 	if (state == MAP_FAILED) {
-		pr_inf_skip("%s: cannot mmap anonymous state structure: "
+		pr_inf_skip("%s: failed to mmap %zu byte anonymous state structure%s, "
 		       "errno=%d (%s), skipping stressor\n",
-			args->name, errno, strerror(errno));
+			args->name, sizeof(*state),
+			stress_get_memfree_str(), errno, strerror(errno));
 		ret = EXIT_NO_RESOURCE;
 		goto cleanup;
 	}
@@ -2527,9 +2529,10 @@ static int stress_sysbadaddr(stress_args_t *args)
 	ro_page = stress_mmap_populate(NULL, page_size,
 		PROT_READ, MAP_ANONYMOUS | MAP_SHARED, -1, 0);
 	if (ro_page == MAP_FAILED) {
-		pr_inf_skip("%s: cannot mmap anonymous read-only page: "
+		pr_inf_skip("%s: failed to mmap %zu byte anonymous read-only page%s, "
 		       "errno=%d (%s), skipping stressor\n",
-			args->name, errno, strerror(errno));
+			args->name, page_size,
+			stress_get_memfree_str(), errno, strerror(errno));
 		ret = EXIT_NO_RESOURCE;
 		goto cleanup;
 	}
@@ -2540,9 +2543,10 @@ static int stress_sysbadaddr(stress_args_t *args)
 		PROT_READ | PROT_WRITE,
 		MAP_ANONYMOUS | MAP_SHARED, -1, 0);
 	if (rw_page == MAP_FAILED) {
-		pr_inf_skip("%s: cannot mmap anonymous read-write page: "
+		pr_inf_skip("%s: failed to mmap %zu byte anonymous read-write page%s, "
 		       "errno=%d (%s), skipping stressor\n",
-			args->name, errno, strerror(errno));
+			args->name, page_size << 1,
+			stress_get_memfree_str(), errno, strerror(errno));
 		ret = EXIT_NO_RESOURCE;
 		goto cleanup;
 	}
@@ -2553,9 +2557,10 @@ static int stress_sysbadaddr(stress_args_t *args)
 		PROT_EXEC | PROT_READ,
 		MAP_ANONYMOUS | MAP_SHARED, -1, 0);
 	if (rx_page == MAP_FAILED) {
-		pr_inf_skip("%s: cannot mmap anonymous execute-only page: "
+		pr_inf_skip("%s: failed to mmap %zu byte anonymous execute-only page%s, "
 		       "errno=%d (%s), skipping stressor\n",
-			args->name, errno, strerror(errno));
+			args->name, page_size,
+			stress_get_memfree_str(), errno, strerror(errno));
 		ret = EXIT_NO_RESOURCE;
 		goto cleanup;
 	}
@@ -2565,9 +2570,10 @@ static int stress_sysbadaddr(stress_args_t *args)
 	no_page = stress_mmap_populate(NULL, page_size,
 		PROT_NONE, MAP_ANONYMOUS | MAP_SHARED, -1, 0);
 	if (no_page == MAP_FAILED) {
-		pr_inf_skip("%s: cannot mmap anonymous prot-none page: "
+		pr_inf_skip("%s: failed to mmap %zu anonymous prot-none page%s, "
 		       "errno=%d (%s), skipping stressor\n",
-			args->name, errno, strerror(errno));
+			args->name, page_size,
+			stress_get_memfree_str(), errno, strerror(errno));
 		ret = EXIT_NO_RESOURCE;
 		goto cleanup;
 	}
@@ -2576,9 +2582,10 @@ static int stress_sysbadaddr(stress_args_t *args)
 	wo_page = stress_mmap_populate(NULL, page_size,
 		PROT_WRITE, MAP_ANONYMOUS | MAP_SHARED, -1, 0);
 	if (wo_page == MAP_FAILED) {
-		pr_inf_skip("%s: cannot mmap anonymous write-only page: "
+		pr_inf_skip("%s: failed to mmap %zu byte anonymous write-only page%s, "
 		       "errno=%d (%s), skipping stressor\n",
-			args->name, errno, strerror(errno));
+			args->name, page_size,
+			stress_get_memfree_str(), errno, strerror(errno));
 		ret = EXIT_NO_RESOURCE;
 		goto cleanup;
 	}
@@ -2627,6 +2634,6 @@ cleanup:
 
 const stressor_info_t stress_sysbadaddr_info = {
 	.stressor = stress_sysbadaddr,
-	.class = CLASS_OS,
+	.classifier = CLASS_OS,
 	.help = help
 };
